"""Library specified for iNels BUS."""

from .const import VERSION

__version__ = VERSION
